@@ -5,7 +5,7 @@ Example source code for using the argtable2 library to implement:
        [--version] <file> [<file>]...
 
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2009 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2010 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -88,7 +88,9 @@ int main(int argc, char **argv)
         printf("Usage: %s", progname);
         arg_print_syntax(stdout,argtable,"\n");
         printf("This program demonstrates the use of the argtable2 library\n");
-        printf("for parsing command line arguments.\n");
+        printf("for parsing command line arguments. Argtable accepts integers\n");
+        printf("in decimal (123), hexadecimal (0xff), octal (0o123) and binary\n");
+        printf("(0b101101) formats. Suffixes KB, MB and GB are also accepted.\n");
         arg_print_glossary(stdout,argtable,"  %-25s %s\n");
         exitcode=0;
         goto exit;
